@@ -16,16 +16,18 @@ COCO_90_LABEL_DICT.update({ii: "Unknown" for ii in INVALID_ID_90})
 COCO_80_to_90_LABEL_DICT = {id_80: id_90 for id_80, id_90 in enumerate(set(range(90)) - set(INVALID_ID_90))}
 
 
-def get_anchors(input_shape=(512, 512, 3), pyramid_levels=[3, 7], aspect_ratios=[0.5, 1, 2], num_scales=3, anchor_scale=4):
+def get_anchors(input_shape=(512, 512, 3), pyramid_levels=[3, 7], aspect_ratios=[1, 2, 0.5], num_scales=3, anchor_scale=4, grid_zero_start=False):
     """
     >>> from keras_cv_attention_models.coco import data
     >>> input_shape = [512, 128]
     >>> anchors = data.get_anchors([512, 128], pyramid_levels=[7])
     >>> data.draw_bboxes(anchors * [512, 128, 512, 128])
+
+    grid_zero_start: grid starts from 0, else from strides // 2. False for efficientdet anchors, True for yolo anchors.
     """
     # base anchors
     scales = [2 ** (ii / num_scales) * anchor_scale for ii in range(num_scales)]
-    aspect_ratios = tf.convert_to_tensor(aspect_ratios)
+    aspect_ratios = tf.convert_to_tensor(aspect_ratios, dtype="float32")
     if len(aspect_ratios.shape) == 1:
         # aspect_ratios = [0.5, 1, 2]
         sqrt_ratios = tf.sqrt(aspect_ratios)
@@ -33,32 +35,36 @@ def get_anchors(input_shape=(512, 512, 3), pyramid_levels=[3, 7], aspect_ratios=
     else:
         # aspect_ratios = [(1, 1), (1.4, 0.7), (0.7, 1.4)]
         ww_ratios, hh_ratios = aspect_ratios[:, 0], aspect_ratios[:, 1]
-    base_anchors_hh = tf.reshape(tf.expand_dims(scales, 0) * tf.expand_dims(hh_ratios, 1), [-1])
-    base_anchors_ww = tf.reshape(tf.expand_dims(scales, 0) * tf.expand_dims(ww_ratios, 1), [-1])
+    base_anchors_hh = tf.reshape(tf.expand_dims(scales, 1) * tf.expand_dims(hh_ratios, 0), [-1])
+    base_anchors_ww = tf.reshape(tf.expand_dims(scales, 1) * tf.expand_dims(ww_ratios, 0), [-1])
     base_anchors_hh_half, base_anchors_ww_half = base_anchors_hh / 2, base_anchors_ww / 2
     base_anchors = tf.stack([base_anchors_hh_half * -1, base_anchors_ww_half * -1, base_anchors_hh_half, base_anchors_ww_half], axis=1)
-    base_anchors = tf.gather(base_anchors, [3, 6, 0, 4, 7, 1, 5, 8, 2])  # re-order according to official generated anchors
+    # base_anchors = tf.gather(base_anchors, [3, 6, 0, 4, 7, 1, 5, 8, 2])  # re-order according to official generated anchors
 
     # make grid
     pyramid_levels = list(range(min(pyramid_levels), max(pyramid_levels) + 1))
 
     # https://github.com/google/automl/tree/master/efficientdet/utils.py#L509
-    feat_sizes = [input_shape[:2]]
+    feature_sizes = [input_shape[:2]]
     for _ in range(max(pyramid_levels)):
-        pre_feat_size = feat_sizes[-1]
-        feat_sizes.append(((pre_feat_size[0] - 1) // 2 + 1, (pre_feat_size[1] - 1) // 2 + 1))
+        pre_feat_size = feature_sizes[-1]
+        feature_sizes.append(((pre_feat_size[0] - 1) // 2 + 1, (pre_feat_size[1] - 1) // 2 + 1))  # ceil mode, like padding="SAME" downsampling
 
     all_anchors = []
     for level in pyramid_levels:
-        stride_hh, stride_ww = feat_sizes[0][0] / feat_sizes[level][0], feat_sizes[0][1] / feat_sizes[level][1]
-        hh_centers = tf.range(stride_hh / 2, input_shape[0], stride_hh)
-        ww_centers = tf.range(stride_ww / 2, input_shape[1], stride_ww)
+        stride_hh, stride_ww = feature_sizes[0][0] / feature_sizes[level][0], feature_sizes[0][1] / feature_sizes[level][1]
+        top, left = (0, 0) if grid_zero_start else (stride_hh / 2, stride_ww / 2)
+        hh_centers = tf.range(top, input_shape[0], stride_hh)
+        ww_centers = tf.range(left, input_shape[1], stride_ww)
         ww_grid, hh_grid = tf.meshgrid(ww_centers, hh_centers)
         grid = tf.reshape(tf.stack([hh_grid, ww_grid, hh_grid, ww_grid], 2), [-1, 1, 4])
         anchors = tf.expand_dims(base_anchors * [stride_hh, stride_ww, stride_hh, stride_ww], 0) + tf.cast(grid, base_anchors.dtype)
         anchors = tf.reshape(anchors, [-1, 4])
         all_anchors.append(anchors)
-    return tf.concat(all_anchors, axis=0) / [input_shape[0], input_shape[1], input_shape[0], input_shape[1]]
+    all_anchors = tf.concat(all_anchors, axis=0) / [input_shape[0], input_shape[1], input_shape[0], input_shape[1]]
+    # if width_first:
+    #      all_anchors = tf.gather(all_anchors, [1, 0, 3, 2], axis=-1)
+    return all_anchors
 
 
 def iou_nd(bboxes, anchors):
@@ -254,24 +260,25 @@ class RandomProcessImageWithBboxes:
         bbox, label, is_not_crowd = tf.cast(objects["bbox"], tf.float32), objects["label"], objects["is_crowd"] == False
         bbox, label = tf.boolean_mask(bbox, is_not_crowd), tf.boolean_mask(label, is_not_crowd)
 
+        image_shape_orign = tf.shape(image)
         if self.magnitude >= 0:
-            processed_image, bbox = random_flip_left_right_with_bboxes(processed_image, bbox)
+            image, bbox = random_flip_left_right_with_bboxes(image, bbox)
         if self.random_crop_min > 0 and self.random_crop_min < 1:
-            scale, offset_y, offset_x = get_image_aspect_aware_random_scale_crop(tf.shape(image), self.target_shape)
+            scale, offset_y, offset_x = get_image_aspect_aware_random_scale_crop(image_shape_orign, self.target_shape)
         else:
             scale, offset_y, offset_x = -1, 0, 0  # Evaluation
-        processed_image, scale = aspect_aware_resize_and_crop_image(
+        image, scale = aspect_aware_resize_and_crop_image(
             image, self.target_shape, scale, offset_y, offset_x, method=self.resize_method, antialias=self.resize_antialias
         )
-        bbox, label = resize_and_crop_bboxes(bbox, label, tf.shape(image), self.target_shape, scale, offset_y, offset_x)
+        bbox, label = resize_and_crop_bboxes(bbox, label, image_shape_orign, self.target_shape, scale, offset_y, offset_x)
 
         if self.magnitude > 0:
-            processed_image = self.randaug(processed_image)
+            image = self.randaug(image)
 
-        processed_image = tf.cast(processed_image, tf.float32)
-        processed_image.set_shape([*self.target_shape[:2], 3])
+        image = tf.cast(image, tf.float32)
+        image.set_shape([*self.target_shape[:2], 3])
 
-        return processed_image, (bbox, label)
+        return image, (bbox, label)
 
 
 def init_dataset(
@@ -281,7 +288,7 @@ def init_dataset(
     buffer_size=1000,
     info_only=False,
     anchor_pyramid_levels=[3, 7],
-    anchor_aspect_ratios=[0.5, 1, 2],
+    anchor_aspect_ratios=[1, 2, 0.5],   # [1, 2, 0.5] matches efficientdet anchors format.
     anchor_num_scales=3,
     anchor_scale=4,
     rescale_mode="torch",  # rescale mode, ["tf", "torch"], or specific `(mean, std)` like `(128.0, 128.0)`
