@@ -5,8 +5,26 @@ from tqdm import tqdm
 
 
 class DecodePredictions:
-    def __init__(self, input_shape=(512, 512, 3), pyramid_levels=[3, 7], anchor_scale=4, **kwargs):
-        self.anchor_scale, self.kwargs = anchor_scale, kwargs
+    """
+    The most simple version decoding prediction and NMS:
+
+    >>> from keras_cv_attention_models import efficientdet, test_images
+    >>> model = efficientdet.EfficientDetD0()
+    >>> preds = model(model.preprocess_input(test_images.dog()))
+
+    # Decode and NMS
+    >>> from keras_cv_attention_models.coco import data
+    >>> input_shape = model.input_shape[1:-1]
+    >>> anchors = data.get_anchors(input_shape=input_shape, pyramid_levels=[3, 7], anchor_scale=4)
+    >>> dd = data.decode_bboxes(preds[0], anchors).numpy()
+    >>> rr = tf.image.non_max_suppression(dd[:, :4], dd[:, 4:].max(-1), score_threshold=0.3, max_output_size=15, iou_threshold=0.5)
+    >>> dd_nms = tf.gather(dd, rr).numpy()
+    >>> bboxes, labels, scores = dd_nms[:, :4], dd_nms[:, 4:].argmax(-1), dd_nms[:, 4:].max(-1)
+    >>> print(f"{bboxes = }, {labels = }, {scores = }")
+    >>> # bboxes = array([[0.433231  , 0.54432285, 0.8778939 , 0.8187578 ]], dtype=float32), labels = array([17]), scores = array([0.85373735], dtype=float32)
+    """
+    def __init__(self, input_shape=(512, 512, 3), pyramid_levels=[3, 7], anchor_scale=4, with_object_score=False, **kwargs):
+        self.anchor_scale, self.with_object_score, self.kwargs = anchor_scale, with_object_score, kwargs
         self.pyramid_levels = list(range(min(pyramid_levels), max(pyramid_levels) + 1))
         if input_shape[0] is not None:
             self.__init_anchor__(input_shape)
@@ -54,12 +72,19 @@ class DecodePredictions:
         if input_shape is not None:
             self.__init_anchor__(input_shape)
 
+        if self.with_object_score: # YOLO outputs: [bboxes, classses_score, object_score]
+            pred, object_scores = pred[:, :-1], pred[:, -1]
+
         if topk > 0:
             bbs, ccs, labels, picking_indices = self.__topk_class_boxes_single__(pred, topk)
             anchors = tf.gather(self.anchors, picking_indices)
+            if self.with_object_score:
+                ccs *= tf.gather(object_scores, picking_indices)
         else:
             bbs, ccs, labels = pred[:, :4], tf.reduce_max(pred[:, 4:], axis=-1), tf.argmax(pred[:, 4:], axis=-1)
             anchors = self.anchors
+            if self.with_object_score:
+                ccs *= object_scores
 
         bbs_decoded = data.decode_bboxes(bbs, anchors)
         iou_threshold, soft_nms_sigma = (1.0, iou_or_sigma / 2) if method.lower() == "gaussian" else (iou_or_sigma, 0.0)
@@ -172,7 +197,7 @@ def run_coco_evaluation(
     eval_dataset = init_eval_dataset(data_name, input_shape, batch_size, rescale_mode, resize_method, resize_antialias)
     if take_samples > 0:
         eval_dataset = eval_dataset.take(take_samples)
-    if hasattr(model, "decode_predictions"):
+    if hasattr(model, "decode_predictions") and model.decode_predictions is not None:
         pred_decoder = model.decode_predictions
     else:
         pred_decoder = DecodePredictions(input_shape, pyramid_levels=pyramid_levels, anchor_scale=anchor_scale, **anchor_kwargs)
